@@ -5,33 +5,35 @@ authenticating peers
 '''
 
 # Import python libs
-import os
-import sys
+import cPickle as pickle
+import hashlib
 import hmac
 import logging
+import os
+import sys
 import tempfile
-import random
-import hashlib
-import time
-import string
-import cPickle as pickle
+
 # Import Cryptography libs
-from M2Crypto import RSA
 from Crypto.Cipher import AES
+from M2Crypto import RSA
+
 # Import zeromq libs
 import zmq
+
 # Import salt utils
-import salt.utils
 import salt.payload
+import salt.utils
 
 log = logging.getLogger(__name__)
 
+
 def foo_pass(self, data=''):
     '''
     used as a workaround for the no-passphrase issue in M2Crypto.RSA
     '''
     return 'foo'
 
+
 def gen_keys(keydir, keyname, keysize):
     '''
     Generate a keypair for use with salt
@@ -46,6 +48,7 @@ def gen_keys(keydir, keyname, keysize):
     os.chmod(priv, 256)
     return key
 
+
 class MasterKeys(dict):
     '''
     The Master Keys class is used to manage the public key pair used for
@@ -96,9 +99,9 @@ class Auth(object):
     def __init__(self, opts):
         self.opts = opts
         self.rsa_path = os.path.join(self.opts['pki_dir'], 'minion.pem')
-        if self.opts.has_key('syndic_master'):
+        if 'syndic_master' in self.opts:
             self.mpub = 'syndic_master.pub'
-        elif self.opts.has_key('alert_master'):
+        elif 'alert_master' in self.opts:
             self.mpub = 'monitor_master.pub'
         else:
             self.mpub = 'minion_master.pub'
@@ -188,13 +191,13 @@ class Auth(object):
         payload = salt.payload.package(self.minion_sign_in_payload())
         socket.send(payload)
         payload = salt.payload.unpackage(socket.recv())
-        if payload.has_key('load'):
-            if payload['load'].has_key('ret'):
+        if 'load' in payload:
+            if 'ret' in payload['load']:
                 if not payload['load']['ret']:
                     log.critical(
                         'The Salt Master has rejected this minion\'s public '
-                        'key!\nTo repair this issue, delete the public key for '
-                        'this minion on the Salt Master and restart this '
+                        'key!\nTo repair this issue, delete the public key '
+                        'for this minion on the Salt Master and restart this '
                         'minion.\nOr restart the Salt Master in open mode to '
                         'clean out the keys. The Salt Minion will now exit.'
                     )
@@ -221,7 +224,12 @@ class Auth(object):
         return auth
 
 
-class AuthenticationError(Exception): pass
+class AuthenticationError(Exception):
+    '''
+    Custom exception class.
+    '''
+
+    pass
 
 
 class Crypticle(object):
