@@ -8,12 +8,16 @@ will always be executed first, so that any grains loaded here in the core
 module can be overwritten just by returning dict keys with the same value
 as those returned here
 '''
+
 # This needs some refactoring, I made it "as fast as I could" and could be a
 # lot clearer, so far it is spaghetti code
 # Import python modules
+
 import os
 import socket
 import subprocess
+import sys
+
 
 def _kernel():
     '''
@@ -30,12 +34,13 @@ def _kernel():
     else:
         grains['kernelrelease'] = subprocess.Popen(['uname', '-r'],
             stdout=subprocess.PIPE).communicate()[0].strip()
-    if not grains.has_key('kernel'):
+    if 'kernel' not in grains:
         grains['kernel'] = 'Unknown'
     if not grains['kernel']:
         grains['kernel'] = 'Unknown'
     return grains
 
+
 def _linux_cpudata():
     '''
     Return the cpu information for Linux systems architecture
@@ -65,14 +70,15 @@ def _linux_cpudata():
                 grains['cpu_model'] = comps[1].strip()
             elif comps[0].strip() == 'flags':
                 grains['cpu_flags'] = comps[1].split()
-    if not grains.has_key('num_cpus'):
+    if 'num_cpus' not in grains:
         grains['num_cpus'] = 0
-    if not grains.has_key('cpu_model'):
+    if 'cpu_model' not in grains:
         grains['cpu_model'] = 'Unknown'
-    if not grains.has_key('cpu_flags'):
+    if 'cpu_flags' not in grains:
         grains['cpu_flags'] = []
     return grains
 
+
 def _freebsd_cpudata():
     '''
     Return cpu information for FreeBSD systems
@@ -96,6 +102,7 @@ def _freebsd_cpudata():
     grains['cpu_flags'] = []
     return grains
 
+
 def _memdata(osdata):
     '''
     Gather information about the system memory
@@ -111,16 +118,17 @@ def _memdata(osdata):
                 if not len(comps) > 1:
                     continue
                 if comps[0].strip() == 'MemTotal':
-                    grains['mem_total'] = int(comps[1].split()[0])/1024
+                    grains['mem_total'] = int(comps[1].split()[0]) / 1024
     elif osdata['kernel'] == 'FreeBSD':
         mem = subprocess.Popen(
                 '/sbin/sysctl hw.physmem',
                 shell=True,
                 stdout=subprocess.PIPE
                 ).communicate()[0].split(':')[1].strip()
-        grains['mem_total'] = str(int(mem)/1024/1024)
+        grains['mem_total'] = str(int(mem) / 1024 / 1024)
     return grains
 
+
 def _virtual(osdata):
     '''
     Returns what type of virtual hardware is under the hood, kvm or physical
@@ -151,6 +159,7 @@ def _virtual(osdata):
             grains['virtual'] = 'kvm'
     return grains
 
+
 def _ps(osdata):
     '''
     Return the ps grain
@@ -160,6 +169,7 @@ def _ps(osdata):
             'FreeBSD NetBSD OpenBSD Darwin'.count(osdata['os']) else 'ps -ef'
     return grains
 
+
 def os_data():
     '''
     Return grains pertaining to the operating system
@@ -171,12 +181,12 @@ def os_data():
             grains['os'] = 'Arch'
         elif os.path.isfile('/etc/debian_version'):
             grains['os'] = 'Debian'
-        elif os.path.isfile('/etc/gentoo-version'):
+        elif os.path.isfile('/etc/gentoo-release'):
             grains['os'] = 'Gentoo'
         elif os.path.isfile('/etc/fedora-version'):
             grains['os'] = 'Fedora'
         elif os.path.isfile('/etc/mandriva-version'):
-            grains['os'] =  'Mandriva'
+            grains['os'] = 'Mandriva'
         elif os.path.isfile('/etc/mandrake-version'):
             grains['os'] = 'Mandrake'
         elif os.path.isfile('/etc/meego-version'):
@@ -234,6 +244,7 @@ def os_data():
     grains.update(_ps(grains))
     return grains
 
+
 def hostname():
     '''
     Return fqdn, hostname, domainname
@@ -253,6 +264,7 @@ def hostname():
         grains['domain'] = ''
     return grains
 
+
 def path():
     '''
     Return the path
@@ -261,4 +273,27 @@ def path():
     #   path
     return {'path': os.environ['PATH'].strip()}
 
+def pythonversion():
+    '''
+    Return the Python version
+    '''
+    # Provides:
+    #   pythonversion
+    return {'pythonversion': list(sys.version_info)}
 
+def pythonpath():
+    '''
+    Return the Python path
+    '''
+    # Provides:
+    #   pythonpath
+    return {'pythonpath': sys.path}
+
+def saltpath():
+    '''
+    Return the path of the salt module
+    '''
+    # Provides:
+    #   saltpath
+    path = os.path.abspath(os.path.join(__file__, os.path.pardir))
+    return {'saltpath': os.path.dirname(path)}
