@@ -2,38 +2,41 @@
 This module contains all fo the routines needed to set up a master server, this
 involves preparing the three listeners and the workers needed by the master.
 '''
+
 # Import python modules
+import cPickle as pickle
+import datetime
+import hashlib
+import logging
+import multiprocessing
 import os
 import re
 import shutil
-import hashlib
-import logging
 import tempfile
-import multiprocessing
 import time
-import datetime
-import cPickle as pickle
+
 # Import zeromq
+from M2Crypto import RSA
 import zmq
+
 # Import salt modules
-import salt.utils
+import salt.client
 import salt.crypt
 import salt.payload
-import salt.client
-# Import cryptography modules
-from M2Crypto import RSA
+import salt.utils
+
 
 log = logging.getLogger(__name__)
 
+
 def prep_jid(cachedir, load):
     '''
     Parses the job return directory, generates a job id and sets up the
     job id directory.
     '''
     jid_root = os.path.join(cachedir, 'jobs')
-    jid = datetime.datetime.strftime(
-        datetime.datetime.now(), '%Y%m%d%H%M%S%f'
-    )
+    jid = "{0:%Y%m%d%H%M%S%f}".format(datetime.datetime.now())
+
     jid_dir = os.path.join(jid_root, jid)
     if not os.path.isdir(jid_dir):
         os.makedirs(jid_dir)
@@ -69,12 +72,13 @@ class SMaster(object):
         '''
         log.info('Preparing the root key for local communication')
         keyfile = os.path.join(self.opts['cachedir'], '.root_key')
-        key = salt.crypt.Crypticle.generate_key_string()
         if os.path.isfile(keyfile):
             return open(keyfile, 'r').read()
-        open(keyfile, 'w+').write(key)
-        os.chmod(keyfile, 256)
-        return key
+        else:
+            key = salt.crypt.Crypticle.generate_key_string()
+            open(keyfile, 'w+').write(key)
+            os.chmod(keyfile, 256)
+            return key
 
 
 class Master(SMaster):
@@ -92,9 +96,8 @@ class Master(SMaster):
         Clean out the old jobs
         '''
         while True:
-            cur = datetime.datetime.strftime(
-                datetime.datetime.now(), '%Y%m%d%H'
-            )
+            cur = "{0:%Y%m%d%H}".format(datetime.datetime.now())
+
             if self.opts['keep_jobs'] == 0:
                 return
             jid_root = os.path.join(self.opts['cachedir'], 'jobs')
@@ -169,12 +172,12 @@ class ReqServer(object):
         self.context = zmq.Context(self.opts['worker_threads'])
         # Prepare the zeromq sockets
         self.uri = 'tcp://%(interface)s:%(ret_port)s' % self.opts
-        self.clients = self.context.socket(zmq.XREP)
-        self.workers = self.context.socket(zmq.XREQ)
+        self.clients = self.context.socket(zmq.ROUTER)
+        self.workers = self.context.socket(zmq.DEALER)
         self.w_uri = 'ipc://{0}'.format(
             os.path.join(self.opts['sock_dir'], 'workers.ipc')
             )
-        # Prepare the aes key
+        # Prepare the AES key
         self.key = key
         self.crypticle = crypticle
 
@@ -195,7 +198,7 @@ class ReqServer(object):
                     self.clear_funcs).start()
 
         self.workers.bind(self.w_uri)
-        
+
         zmq.device(zmq.QUEUE, self.clients, self.workers)
 
     def start_publisher(self):
@@ -279,7 +282,7 @@ class MWorker(multiprocessing.Process):
             data = self.crypticle.loads(load)
         except:
             return ''
-        if not data.has_key('cmd'):
+        if 'cmd' not in data:
             log.error('Recieved malformed command {0}'.format(data))
             return {}
         log.info('AES payload received with command {0}'.format(data['cmd']))
@@ -310,7 +313,7 @@ class AESFuncs(object):
         '''
         fnd = {'path': '',
                'rel': ''}
-        if not self.opts['file_roots'].has_key(env):
+        if env not in self.opts['file_roots']:
             return fnd
         for root in self.opts['file_roots'][env]:
             full = os.path.join(root, path)
@@ -350,9 +353,7 @@ class AESFuncs(object):
         '''
         ret = {'data': '',
                'dest': ''}
-        if not load.has_key('path')\
-                or not load.has_key('loc')\
-                or not load.has_key('env'):
+        if 'path' not in load or 'loc' not in load or 'env' not in load:
             return ret
         fnd = self.__find_file(load['path'], load['env'])
         if not fnd['path']:
@@ -367,8 +368,7 @@ class AESFuncs(object):
         '''
         Return a file hash, the hash type is set in the master config file
         '''
-        if not load.has_key('path')\
-                or not load.has_key('env'):
+        if 'path' not in load or 'env' not in load:
             return ''
         path = self.__find_file(load['path'], load['env'])['path']
         if not path:
@@ -385,7 +385,7 @@ class AESFuncs(object):
         environment
         '''
         ret = []
-        if not self.opts['file_roots'].has_key(load['env']):
+        if load['env'] not in self.opts['file_roots']:
             return ret
         for path in self.opts['file_roots'][load['env']]:
             for root, dirs, files in os.walk(path):
@@ -412,9 +412,7 @@ class AESFuncs(object):
         Handle the return data sent from the minions
         '''
         # If the return data is invalid, just ignore it
-        if not load.has_key('return')\
-                or not load.has_key('jid')\
-                or not load.has_key('id'):
+        if 'return' not in load or 'jid' not in load or 'id' not in load:
             return False
         log.info('Got return from %(id)s for job %(jid)s', load)
         jid_dir = os.path.join(self.opts['cachedir'], 'jobs', load['jid'])
@@ -429,7 +427,7 @@ class AESFuncs(object):
             os.makedirs(hn_dir)
         pickle.dump(load['return'],
                 open(os.path.join(hn_dir, 'return.p'), 'w+'))
-        if load.has_key('out'):
+        if 'out' in load:
             pickle.dump(load['out'],
                     open(os.path.join(hn_dir, 'out.p'), 'w+'))
 
@@ -439,8 +437,7 @@ class AESFuncs(object):
         individual minions.
         '''
         # Verify the load
-        if not load.has_key('return') \
-                or not load.has_key('jid'):
+        if 'return' not in load or 'jid' not in load:
             return None
         # Format individual return loads
         for key, item in load['return'].items():
@@ -468,23 +465,24 @@ class AESFuncs(object):
         execute commands from the test module
         '''
         # Verify that the load is valid
-        if not self.opts.has_key('peer'):
+        if 'peer' not in self.opts:
             return {}
         if not isinstance(self.opts['peer'], dict):
             return {}
-        if not clear_load.has_key('fun')\
-                or not clear_load.has_key('arg')\
-                or not clear_load.has_key('tgt')\
-                or not clear_load.has_key('ret')\
-                or not clear_load.has_key('tok')\
-                or not clear_load.has_key('id'):
+        # FIXME: rewrite this ugly monster using eg any()
+        if 'fun' not in clear_load\
+                or 'arg' not in clear_load\
+                or 'tgt' not in clear_load\
+                or 'ret' not in clear_load\
+                or 'tok' not in clear_load\
+                or 'id' not in clear_load:
             return {}
         # If the command will make a recursive publish don't run
         if re.match('publish.*', clear_load['fun']):
             return {}
         # Check the permisions for this minion
         if not self.__verify_minion(clear_load['id'], clear_load['tok']):
-            # The minion is not who it says it is! 
+            # The minion is not who it says it is!
             # We don't want to listen to it!
             return {}
         perms = set()
@@ -500,25 +498,21 @@ class AESFuncs(object):
         if not good:
             return {}
         # Set up the publication payload
-        jid_dir = os.path.join(
-            self.opts['cachedir'],
-            'jobs',
-            clear_load['jid'])
-        pickle.dump(clear_load, open(os.path.join(jid_dir, '.load.p'), 'w+'))
+        jid = prep_jid(self.opts['cachedir'], clear_load)
         payload = {'enc': 'aes'}
         load = {
                 'fun': clear_load['fun'],
                 'arg': clear_load['arg'],
                 'tgt': clear_load['tgt'],
-                'jid': clear_load['jid'],
+                'jid': jid,
                 'ret': clear_load['ret'],
                }
         expr_form = 'glob'
         timeout = 0
-        if clear_load.has_key('tgt_type'):
+        if 'tgt_type' in clear_load:
             load['tgt_type'] = clear_load['tgt_type']
             expr_form = load['tgt_type']
-        if clear_load.has_key('timeout'):
+        if 'timeout' in clear_load:
             timeout = clear_load('timeout')
         # Encrypt!
         payload['load'] = self.crypticle.dumps(load)
@@ -532,7 +526,7 @@ class AESFuncs(object):
         pub_sock.send(salt.payload.package(payload))
         # Run the client get_returns method
         return self.local.get_returns(
-                clear_load['jid'],
+                jid,
                 self.local.check_minions(
                     clear_load['tgt'],
                     expr_form
@@ -556,6 +550,7 @@ class AESFuncs(object):
         # AES Encrypt the return
         return self.crypticle.dumps(ret)
 
+
 class ClearFuncs(object):
     '''
     Set up functions that are safe to execute when commands sent to the master
@@ -695,7 +690,8 @@ class ClearFuncs(object):
         # Verify that the caller has root on master
         if not clear_load.pop('key') == self.key:
             return ''
-        jid_dir = os.path.join(self.opts['cachedir'], 'jobs', clear_load['jid'])
+        jid_dir = (os.path.join(self.opts['cachedir'],
+                   'jobs', clear_load['jid']))
         # Verify the jid dir
         if not os.path.isdir(jid_dir):
             os.makedirs(jid_dir)
@@ -710,9 +706,9 @@ class ClearFuncs(object):
                 'jid': clear_load['jid'],
                 'ret': clear_load['ret'],
                }
-        if clear_load.has_key('tgt_type'):
+        if 'tgt_type' in clear_load:
             load['tgt_type'] = clear_load['tgt_type']
-        if clear_load.has_key('to'):
+        if 'to' in clear_load:
             load['to'] = clear_load['to']
         payload['load'] = self.crypticle.dumps(load)
         # Send 0MQ to the publisher
