@@ -1,29 +1,30 @@
 '''
 Routines to set up a minion
 '''
+
 # Import python libs
-import os
-import distutils.sysconfig
 import glob
-import re
-import time
 import logging
-import tempfile
-import traceback
-import shutil
-import threading
 import multiprocessing
+import os
+import re
+import shutil
+import tempfile
+import threading
+import time
+import traceback
 
 # Import zeromq libs
 import zmq
+
 # Import salt libs
-import salt.crypt
 from salt.crypt import AuthenticationError
-import salt.utils
+import salt.client
+import salt.crypt
+import salt.loader
 import salt.modules
 import salt.returners
-import salt.loader
-import salt.client
+import salt.utils
 
 log = logging.getLogger(__name__)
 
@@ -35,7 +36,12 @@ log = logging.getLogger(__name__)
 # 5. connect to the publisher
 # 6. handle publications
 
-class MinionError(Exception): pass
+
+class MinionError(Exception):
+    '''
+    Custom exception class.
+    '''
+    pass
 
 
 class SMinion(object):
@@ -110,22 +116,21 @@ class Minion(object):
             self.authenticate()
             data = self.crypticle.loads(load)
         # Verify that the publication is valid
-        if not data.has_key('tgt')\
-                or not data.has_key('jid')\
-                or not data.has_key('fun')\
-                or not data.has_key('arg'):
+        if 'tgt' not in data or 'jid' not in data or 'fun' not in data \
+           or 'arg' not in data:
             return
         # Verify that the publication applies to this minion
-        if data.has_key('tgt_type'):
-            if not getattr(self.matcher, data['tgt_type'] + '_match')(data['tgt']):
+        if 'tgt_type' in data:
+            if not getattr(self.matcher,
+                           data['tgt_type'] + '_match')(data['tgt']):
                 return
         else:
             if not self.matcher.glob_match(data['tgt']):
                 return
-        # If the minion does not have the function, don't execute, this prevents
-        # minions that could not load a minion module from returning a
-        # predictable exception
-        #if not self.functions.has_key(data['fun']):
+        # If the minion does not have the function, don't execute,
+        # this prevents minions that could not load a minion module
+        # from returning a predictable exception
+        #if data['fun'] not in self.functions:
         #    return
         log.debug('Executing command {0[fun]} with jid {0[jid]}'.format(data))
         self._handle_decoded_payload(data)
@@ -144,7 +149,8 @@ class Minion(object):
 
     def _handle_decoded_payload(self, data):
         '''
-        Override this method if you wish to handle the decoded data differently.
+        Override this method if you wish to handle the decoded
+        data differently.
         '''
         if self.opts['multiprocessing']:
             if type(data['fun']) == type(list()):
@@ -216,6 +222,7 @@ class Minion(object):
             for index in range(0, len(data['arg'][ind])):
                 try:
                     arg = eval(data['arg'][ind][index])
+                    # FIXME: do away the ugly here...
                     if isinstance(arg, str) \
                             or isinstance(arg, list) \
                             or isinstance(arg, int) \
@@ -308,8 +315,8 @@ class Minion(object):
         '''
         Lock onto the publisher. This is the main event loop for the minion
         '''
-        master_pub = 'tcp://' + self.opts['master_ip'] + ':'\
-                   + str(self.publish_port)
+        master_pub = ('tcp://' + self.opts['master_ip'] +
+                      ':' + str(self.publish_port))
         context = zmq.Context()
         socket = context.socket(zmq.SUB)
         socket.setsockopt(zmq.SUBSCRIBE, '')
@@ -367,19 +374,18 @@ class Syndic(salt.client.LocalClient, Minion):
             self.authenticate()
             data = self.crypticle.loads(load)
         # Verify that the publication is valid
-        if not data.has_key('tgt')\
-                or not data.has_key('jid')\
-                or not data.has_key('fun')\
-                or not data.has_key('to')\
-                or not data.has_key('arg'):
+        if 'tgt' not in data or 'jid' not in data or 'fun' not in data \
+           or 'to' not in data or 'arg' not in data:
             return
         data['to'] = int(data['to']) - 1
-        log.debug('Executing syndic command {0[fun]} with jid {0[jid]}'.format(data))
+        log.debug(('Executing syndic command {0[fun]} with jid {0[jid]}'
+                  .format(data)))
         self._handle_decoded_payload(data)
 
     def _handle_decoded_payload(self, data):
         '''
-        Override this method if you wish to handle the decoded data differently.
+        Override this method if you wish to handle
+        the decoded data differently.
         '''
         if self.opts['multiprocessing']:
             multiprocessing.Process(
@@ -395,7 +401,7 @@ class Syndic(salt.client.LocalClient, Minion):
         Take the now clear load and forward it on to the client cmd
         '''
         # Set up default expr_form
-        if not data.has_key('expr_form'):
+        if 'expr_form' not in data:
             data['expr_form'] = 'glob'
         # Send out the publication
         pub_data = self.pub(
@@ -418,6 +424,7 @@ class Syndic(salt.client.LocalClient, Minion):
         # Return the publication data up the pipe
         self._return_pub(ret, '_syndic_return')
 
+
 class Matcher(object):
     '''
     Use to return the value for matching calls from the master
@@ -429,7 +436,7 @@ class Matcher(object):
         else:
             self.functions = functions
 
-    def confirm_top(self, match, data):            
+    def confirm_top(self, match, data):
         '''
         Takes the data passed to a top file environment and determines if the
         data matches this minion
@@ -437,7 +444,7 @@ class Matcher(object):
         matcher = 'glob'
         for item in data:
             if type(item) == type(dict()):
-                if item.has_key('match'):
+                if 'match' in item:
                     matcher = item['match']
         if hasattr(self, matcher + '_match'):
             return getattr(self, matcher + '_match')(match)
@@ -478,7 +485,7 @@ class Matcher(object):
         if len(comps) < 2:
             log.error('Got insufficient arguments for grains from master')
             return False
-        if not self.opts['grains'].has_key(comps[0]):
+        if comps[0] not in self.opts['grains']:
             log.error('Got unknown grain from master: %s', comps[0])
             return False
         return bool(re.match(comps[1], self.opts['grains'][comps[0]]))
@@ -487,7 +494,7 @@ class Matcher(object):
         '''
         Runs a function and return the exit code
         '''
-        if not self.functions.has_key(tgt):
+        if tgt not in self.functions:
             return False
         return(self.functions[tgt]())
 
@@ -517,7 +524,7 @@ class FileClient(object):
         if not path.startswith('salt://'):
             raise MinionError('Unsupported path')
         return path[7:]
-        
+
     def get_file(self, path, dest='', makedirs=False, env='base'):
         '''
         Get a single file from the salt-master
@@ -569,8 +576,8 @@ class FileClient(object):
 
     def cache_files(self, paths, env='base'):
         '''
-        Download a list of files stored on the master and put them in the minion
-        file cache
+        Download a list of files stored on the master and put them
+        in the minion file cache
         '''
         ret = []
         for path in paths:
@@ -623,7 +630,7 @@ class FileClient(object):
         self.socket.send_pyobj(payload)
         return self.auth.crypticle.loads(self.socket.recv_pyobj())
 
-    def list_env(path, env='base'):
+    def list_env(self, path, env='base'):
         '''
         Return a list of the files in the file server's specified environment
         '''
@@ -641,10 +648,8 @@ class FileClient(object):
         '''
         if sls.count('.'):
             sls = sls.replace('.', '/')
-        for path in [
-                'salt://' + sls + '.sls', 
-                os.path.join('salt://', sls, 'init.sls')
-                ]:
+        for path in ['salt://' + sls + '.sls',
+                     os.path.join('salt://', sls, 'init.sls')]:
             dest = self.cache_file(path, env)
             if dest:
                 return dest
@@ -652,11 +657,10 @@ class FileClient(object):
 
     def master_opts(self):
         '''
-        Return the master opts data 
+        Return the master opts data
         '''
         payload = {'enc': 'aes'}
         load = {'cmd': '_master_opts'}
         payload['load'] = self.auth.crypticle.dumps(load)
         self.socket.send_pyobj(payload)
         return self.auth.crypticle.loads(self.socket.recv_pyobj())
-
