@@ -1,64 +1,68 @@
 '''
-Support for apt
+Support for APT (Advanced Packaging Tool)
 '''
 
-import subprocess
 
 def __virtual__():
     '''
     Confirm this module is on a Debian based system
     '''
-    
+
     return 'pkg' if __grains__['os'] == 'Debian' else False
 
+
 def available_version(name):
     '''
     The available version of the package in the repository
 
-    CLI Example:
-    salt '*' pkg.available_version <package name>
+    CLI Example::
+
+        salt '*' pkg.available_version <package name>
     '''
     version = ''
-    cmd = 'apt-cache show ' + name + ' | grep Version'
-    
-    out = subprocess.Popen(cmd,
-            shell=True,
-            stdout=subprocess.PIPE).communicate()[0]
-    
+    cmd = 'apt-cache show {0} | grep Version'.format(name)
+
+    out = __salt__['cmd.run_stdout'](cmd)
+
     version_list = out.split()
     if len(version_list) >= 2:
         version = version_list[1]
-    
+
     return version
 
+
 def version(name):
     '''
     Returns a string representing the package version or an empty string if not
     installed
 
-    CLI Example:
-    salt '*' pkg.version <package name>
+    CLI Example::
+
+        salt '*' pkg.version <package name>
     '''
     pkgs = list_pkgs(name)
-    if pkgs.has_key(name):
+    if name in pkgs:
         return pkgs[name]
     else:
         return ''
 
+
 def refresh_db():
     '''
-    Updates the apt database to latest packages based upon repositories
-    
-    Returns a dict: {'<database name>': Bool}
-    
-    CLI Example:
-    salt '*' pkg.refresh_db    
+    Updates the APT database to latest packages based upon repositories
+
+    Returns a dict::
+
+        {'<database name>': Bool}
+
+    CLI Example::
+
+        salt '*' pkg.refresh_db
     '''
     cmd = 'apt-get update'
-    out = subprocess.Popen(cmd,
-            shell=True,
-            stdout=subprocess.PIPE).communicate()[0].split('\n')
-    
+
+    out = __salt__['cmd.run_stdout'](cmd)
+
     servers = {}
     for line in out:
         cols = line.split()
@@ -68,10 +72,11 @@ def refresh_db():
         if cols[0].count('Get'):
             servers[ident] = True
         else:
-            servers[ident]  = False
-    
+            servers[ident] = False
+
     return servers
-    
+
+
 def install(pkg, refresh=False):
     '''
     Install the passed package
@@ -85,17 +90,17 @@ def install(pkg, refresh=False):
 
         salt '*' pkg.install <package name>
     '''
-    if(refresh):
+    if refresh:
         refresh_db()
-    
+
     ret_pkgs = {}
     old_pkgs = list_pkgs()
-    cmd = 'apt-get -y install ' + pkg
-    subprocess.call(cmd, shell=True)
+    cmd = 'apt-get -y install {0}'.format(pkg)
+    __salt__['cmd.retcode'](cmd)
     new_pkgs = list_pkgs()
-    
+
     for pkg in new_pkgs:
-        if old_pkgs.has_key(pkg):
+        if pkg in old_pkgs:
             if old_pkgs[pkg] == new_pkgs[pkg]:
                 continue
             else:
@@ -104,64 +109,63 @@ def install(pkg, refresh=False):
         else:
             ret_pkgs[pkg] = {'old': '',
                          'new': new_pkgs[pkg]}
-    
+
     return ret_pkgs
 
+
 def remove(pkg):
     '''
-    Remove a single package via apt-get remove
-    
-    Return a list containing the names of the removed packages:
-    
-    CLI Example:
-    salt '*' pkg.remove <package name>
+    Remove a single package via ``aptitude remove``
+
+    Returns a list containing the names of the removed packages.
+
+    CLI Example::
+
+        salt '*' pkg.remove <package name>
     '''
     ret_pkgs = []
     old_pkgs = list_pkgs()
-    
-    cmd = 'apt-get -y remove ' + pkg
-    subprocess.call(cmd, shell=True)
-    new = list_pkgs()
-    
+
+    cmd = 'apt-get -y remove {0}'.format(pkg)
+    __salt__['cmd.retcode'](cmd)
+    new_pkgs = list_pkgs()
     for pkg in old_pkgs:
-        if not new_pkgs.has_key(pkg):
+        if pkg not in new_pkgs:
             ret_pkgs.append(pkg)
-    
+
     return ret_pkgs
 
+
 def purge(pkg):
     '''
-    Remove a package via apt-get along with all configuration files and
-    unused dependencies as determined by apt-get autoremove
-    
+    Remove a package via aptitude along with all configuration files and
+    unused dependencies.
+
     Returns a list containing the names of the removed packages
-    
-    CLI Example:
-    salt '*' pkg.purge <package name>
+
+    CLI Example::
+
+        salt '*' pkg.purge <package name>
     '''
     ret_pkgs = []
     old_pkgs = list_pkgs()
-    
+
     # Remove inital package
-    purge_cmd = 'apt-get -y purge ' + pkg
-    subprocess.call(purge_cmd, shell=True)
+    purge_cmd = 'apt-get -y purge {0}'.format(pkg)
+    __salt__['cmd.retcode'](purge_cmd)
     
-    # Remove any dependencies that are no longer needed
-    autoremove_cmd = 'apt-get -y autoremove'
-    subprocess.call(purge_cmd, shell=True)
-    
-    new = list_pkgs()
+    new_pkgs = list_pkgs()
     
     for pkg in old_pkgs:
-        if not new_pkgs.has_key(pkg):
+        if pkg not in new_pkgs:
             ret_pkgs.append(pkg)
-    
+
     return ret_pkgs
-    
+
 
 def upgrade(refresh=True):
     '''
-    Upgrades all packages via apt-get dist-upgrade
+    Upgrades all packages via aptitude full-upgrade
 
     Returns a list of dicts containing the package names, and the new and old
     versions::
@@ -177,18 +181,18 @@ def upgrade(refresh=True):
 
         salt '*' pkg.upgrade
     '''
-    
-    if(update_repos):
+
+    if refresh:
         refresh_db()
-    
+
     ret_pkgs = {}
     old_pkgs = list_pkgs()
     cmd = 'apt-get -y dist-upgrade'
-    subprocess.call(cmd, shell=True)
+    __salt__['cmd.retcode'](cmd)
     new_pkgs = list_pkgs()
-    
+
     for pkg in new_pkgs:
-        if old_pkgs.has_key(pkg):
+        if pkg in old_pkgs:
             if old_pkgs[pkg] == new_pkgs[pkg]:
                 continue
             else:
@@ -197,28 +201,28 @@ def upgrade(refresh=True):
         else:
             ret_pkgs[pkg] = {'old': '',
                          'new': new_pkgs[pkg]}
-    
+
     return ret_pkgs
 
 
 def list_pkgs(regex_string=""):
     '''
-    List the packages currently installed in a dict:
-    {'<package_name>': '<version>'}
+    List the packages currently installed in a dict::
 
-    CLI Example:
-    salt '*' pkg.list_pkgs
+        {'<package_name>': '<version>'}
+
+    CLI Example::
+
+        salt '*' pkg.list_pkgs
     '''
     ret = {}
-    cmd = 'dpkg --list ' + regex_string
-    
-    out = subprocess.Popen(cmd,
-            shell=True,
-            stdout=subprocess.PIPE).communicate()[0].split('\n')
-    
-    for line in out:
+    cmd = 'dpkg --list {0}'.format(regex_string)
+
+    out = __salt__['cmd.run_stdout'](cmd)
+
+    for line in out.split('\n'):
         cols = line.split()
         if len(cols) and cols[0].count('ii'):
             ret[cols[1]] = cols[2]
-    
+
     return ret
