@@ -4,11 +4,11 @@ A module for shelling out
 Keep in mind that this module is insecure, in that it can give whomever has
 access to the master root execution access to all salt minions
 '''
-# Import Python libs
+
+import logging
+import os
 import subprocess
 import tempfile
-import os
-import logging
 
 # Set up logging
 log = logging.getLogger(__name__)
@@ -22,18 +22,21 @@ __outputter__ = {
                  'run': 'txt'
                  }
 
+
 def _is_exec(path):
     '''
     Return true if the passed path exists and is execuatable
     '''
     return os.path.exists(path) and os.access(path, os.X_OK)
 
+
 def run(cmd, cwd=DEFAULT_CWD):
     '''
     Execute the passed command and return the output as a string
 
-    CLI Example:
-    salt '*' cmd.run "ls -l | grep foo | awk '{print $2}'"
+    CLI Example::
+
+        salt '*' cmd.run "ls -l | grep foo | awk '{print $2}'"
     '''
     log.info('Executing command {0} in directory {1}'.format(cmd, cwd))
     out = subprocess.Popen(cmd,
@@ -44,12 +47,14 @@ def run(cmd, cwd=DEFAULT_CWD):
     log.debug(out)
     return out
 
+
 def run_stdout(cmd, cwd=DEFAULT_CWD):
     '''
-    Execute a command, and only return the standard out 
+    Execute a command, and only return the standard out
 
-    CLI Example:
-    salt '*' cmd.run "ls -l | grep foo | awk '{print $2}'"
+    CLI Example::
+
+        salt '*' cmd.run "ls -l | grep foo | awk '{print $2}'"
     '''
     log.info('Executing command {0} in directory {1}'.format(cmd, cwd))
     stdout = subprocess.Popen(cmd,
@@ -59,12 +64,14 @@ def run_stdout(cmd, cwd=DEFAULT_CWD):
     log.debug(stdout)
     return stdout
 
+
 def run_stderr(cmd, cwd=DEFAULT_CWD):
     '''
     Execute a command and only return the standard error
 
-    CLI Example:
-    salt '*' cmd.run "ls -l | grep foo | awk '{print $2}'"
+    CLI Example::
+
+        salt '*' cmd.run "ls -l | grep foo | awk '{print $2}'"
     '''
     log.info('Executing command {0} in directory {1}'.format(cmd, cwd))
     stderr = subprocess.Popen(cmd,
@@ -74,16 +81,18 @@ def run_stderr(cmd, cwd=DEFAULT_CWD):
     log.debug(stderr)
     return stderr
 
+
 def run_all(cmd, cwd=DEFAULT_CWD):
     '''
     Execute the passed command and return a dict of return data
 
-    CLI Example:
-    salt '*' cmd.run_all "ls -l | grep foo | awk '{print $2}'"
+    CLI Example::
+
+        salt '*' cmd.run_all "ls -l | grep foo | awk '{print $2}'"
     '''
     log.info('Executing command {0} in directory {1}'.format(cmd, cwd))
     ret = {}
-    proc =  subprocess.Popen(cmd,
+    proc = subprocess.Popen(cmd,
             shell=True,
             cwd=cwd,
             stdout=subprocess.PIPE,
@@ -102,22 +111,26 @@ def run_all(cmd, cwd=DEFAULT_CWD):
         log.info('stderr: {0}'.format(ret['stderr']))
     return ret
 
+
 def retcode(cmd, cwd=DEFAULT_CWD):
     '''
     Execute a shell command and return the command's return code.
 
-    CLI Example:
-    salt '*' cmd.retcode "file /bin/bash"
+    CLI Example::
+
+        salt '*' cmd.retcode "file /bin/bash"
     '''
     log.info('Executing command {0} in directory {1}'.format(cmd, cwd))
     return subprocess.call(cmd, shell=True, cwd=cwd)
 
+
 def has_exec(cmd):
     '''
     Returns true if the executable is available on the minion, false otherwise
 
-    CLI Example:
-    salt '*' cat
+    CLI Example::
+
+        salt '*' cat
     '''
     if cmd.startswith('/'):
         return _is_exec(cmd)
@@ -127,14 +140,16 @@ def has_exec(cmd):
             return True
     return False
 
+
 def exec_code(lang, code, cwd=DEFAULT_CWD):
     '''
     Pass in two strings, the first naming the executable language, aka -
     python2, python3, ruby, perl, lua, etc. the second string containing
     the code you wish to execute. The stdout and stderr will be returned
 
-    CLI Example:
-    salt '*' cmd.exec_code ruby 'puts "cheese"'
+    CLI Example::
+
+        salt '*' cmd.exec_code ruby 'puts "cheese"'
     '''
     fd, cfn = tempfile.mkstemp()
     open(cfn, 'w+').write(code)
