@@ -1,15 +1,11 @@
 '''
 Minion side functions for salt-cp
 '''
-# Import python libs
-import os
-import hashlib
 
-# Import salt libs
+import os
+
 import salt.minion
 
-# Import Third Party Libs
-import zmq
 
 def recv(files, dest):
     '''
@@ -38,6 +34,7 @@ def recv(files, dest):
 
     return ret
 
+
 def get_file(path, dest, env='base'):
     '''
     Used to get a single file from the salt master
@@ -45,6 +42,7 @@ def get_file(path, dest, env='base'):
     client = salt.minion.FileClient(__opts__)
     return client.get_file(path, dest, False, env)
 
+
 def cache_file(path, env='base'):
     '''
     Used to cache a single file in the local salt-master file cache.
@@ -52,6 +50,7 @@ def cache_file(path, env='base'):
     client = salt.minion.FileClient(__opts__)
     return client.cache_file(path, env)
 
+
 def cache_files(paths, env='base'):
     '''
     Used to gather many files from the master, the gathered files will be
@@ -61,6 +60,7 @@ def cache_files(paths, env='base'):
     client = salt.minion.FileClient(__opts__)
     return client.cache_files(paths, env)
 
+
 def cache_dir(path, env='base'):
     '''
     Download and cache everything under a directory from the master
@@ -68,6 +68,7 @@ def cache_dir(path, env='base'):
     client = salt.minion.FileClient(__opts__)
     return client.cache_dir(path, env)
 
+
 def cache_master(env='base'):
     '''
     Retrieve all of the files on the master and cache them locally
@@ -75,6 +76,7 @@ def cache_master(env='base'):
     client = salt.minion.FileClient(__opts__)
     return client.cache_master(env)
 
+
 def list_master(env='base'):
     '''
     Retrieve all of the files on the master and cache them locally
@@ -82,13 +84,12 @@ def list_master(env='base'):
     client = salt.minion.FileClient(__opts__)
     return client.file_list(env)
 
+
 def hash_file(path, env='base'):
     '''
     Return the hash of a file, to get the hash of a file on the
     salt master file server prepend the path with salt://<file on server>
     otherwise, prepend the file with / for a local file.
-
-    CLI Example:
     '''
     client = salt.minion.FileClient(__opts__)
     return client.hash_file(path, env)
