@@ -1,14 +1,18 @@
 '''
 Module for gathering disk information
 '''
+
+# FIXME: we want module internal calls rather than using subprocess directly
 import subprocess
 
+
 def usage():
     '''
     Return usage information for volumes mounted on this minion
-    
-    CLI Example:
-    salt '*' disk.usage
+
+    CLI Example::
+
+        salt '*' disk.usage
     '''
     cmd = 'df -P'
     ret = {}
@@ -23,9 +27,9 @@ def usage():
         comps = line.split()
         ret[comps[0]] = {
             '1K-blocks': comps[1],
-            'used':      comps[2],
             'available': comps[3],
-            'capacity':  comps[4],
-            'mountpoint':comps[5]
+            'capacity': comps[4],
+            'mountpoint': comps[5],
+            'used': comps[2]
         }
     return ret
