@@ -4,51 +4,61 @@ Package support for FreeBSD
 
 import os
 
+
 def __virtual__():
     '''
     Set the virtual pkg module if the os is Arch
     '''
     return 'pkg' if __grains__['os'] == 'FreeBSD' else False
 
+
 def _list_removed(old, new):
     '''
     List the packages which have been removed between the two package objects
     '''
     pkgs = []
     for pkg in old:
-        if not new.has_key(pkg):
+        if pkg not in new:
             pkgs.append(pkg)
     return pkgs
 
+
+# FIXME: Unused argument 'name' (pylint is your friend)
 def available_version(name):
     '''
     The available version of the package in the repository
 
-    CLI Example:
-    salt '*' pkg.available_version <package name>
+    CLI Example::
+
+        salt '*' pkg.available_version <package name>
     '''
     pass
 
+
 def version(name):
     '''
     Returns a version if the package is installed, else returns an empty string
 
-    CLI Example:
-    salt '*' pkg.version <package name>
+    CLI Example::
+
+        salt '*' pkg.version <package name>
     '''
     pkgs = list_pkgs()
-    if pkgs.has_key(name):
+    if name in pkgs:
         return pkgs[name]
     else:
         return ''
 
+
 def list_pkgs():
     '''
-    List the packages currently installed in a dict:
-    {'<package_name>': '<version>'}
+    List the packages currently installed as a dict::
 
-    CLI Example:
-    salt '*' pkg.list_pkgs
+        {'<package_name>': '<version>'}
+
+    CLI Example::
+
+        salt '*' pkg.list_pkgs
     '''
     ret = {}
     for line in __salt__['cmd.run']('pkg_info').split('\n'):
@@ -58,13 +68,15 @@ def list_pkgs():
         ret['-'.join(comps[0:-1])] = comps[-1]
     return ret
 
+
 def refresh_db():
     '''
     Update the ports tree with portsnap. If the ports tre does not exist it
     will be downloaded and set up.
 
-    CLI Example:
-    salt '*' pkg.refresh_db
+    CLI Example::
+
+        salt '*' pkg.refresh_db
     '''
     __salt__['cmd.run']('portsnap fetch')
     if not os.path.isdir('/usr/ports'):
@@ -72,6 +84,8 @@ def refresh_db():
     else:
         __salt__['cmd.run']('portsnap update')
 
+
+# FIXME: Unused argument 'refresh'
 def install(name, refresh=False):
     '''
     Install the passed package
@@ -81,15 +95,16 @@ def install(name, refresh=False):
         {'<package>': {'old': '<old-version>',
                    'new': '<new-version>']}
 
-    CLI Example:
-    salt '*' pkg.install <package name>
+    CLI Example::
+
+        salt '*' pkg.install <package name>
     '''
     old = list_pkgs()
     __salt__['cmd.retcode']('pkg_add -r {0}'.format(name))
     new = list_pkgs()
     pkgs = {}
     for npkg in new:
-        if old.has_key(npkg):
+        if npkg in old:
             if old[npkg] == new[npkg]:
                 # no change in the package
                 continue
@@ -103,24 +118,26 @@ def install(name, refresh=False):
                           'new': new[npkg]}
     return pkgs
 
+
 def upgrade():
     '''
-    Run a full system upgrade, a "freebsd-update fetch install"
+    Run a full system upgrade, a ``freebsd-update fetch install``
 
     Return a dict containing the new package names and versions::
 
         {'<package>': {'old': '<old-version>',
                    'new': '<new-version>']}
 
-    CLI Example:
-    salt '*' pkg.upgrade
+    CLI Example::
+
+        salt '*' pkg.upgrade
     '''
     old = list_pkgs()
     __salt__['cmd.retcode']('freebsd-update fetch install')
     new = list_pkgs()
     pkgs = {}
     for npkg in new:
-        if old.has_key(npkg):
+        if npkg in old:
             if old[npkg] == new[npkg]:
                 # no change in the package
                 continue
@@ -134,30 +151,33 @@ def upgrade():
                           'new': new[npkg]}
     return pkgs
 
+
 def remove(name):
     '''
     Remove a single package with pkg_delete
 
-    Return a list containing the removed packages:
+    Returns a list containing the removed packages.
 
-    CLI Example:
-    salt '*' pkg.remove <package name>
+    CLI Example::
+
+        salt '*' pkg.remove <package name>
     '''
     old = list_pkgs()
-    if old.has_key(name):
+    if name in old:
         name = '{0}-{1}'.format(name, old[name])
         __salt__['cmd.retcode']('pkg_delete {0}'.format(name))
     new = list_pkgs()
     return _list_removed(old, new)
 
+
 def purge(name):
     '''
     Remove a single package with pkg_delete
 
-    Return a list containing the removed packages:
+    Returns a list containing the removed packages.
 
-    CLI Example:
-    salt '*' pkg.purge <package name>
+    CLI Example::
 
+        salt '*' pkg.purge <package name>
     '''
     return remove(name)
