@@ -1,16 +1,19 @@
 '''
 Manage the information in the hosts file
 '''
+
 import os
 
+
 def list_hosts():
     '''
-    Return the hosts found in the hosts file in this format:
+    Return the hosts found in the hosts file in this format::
 
-    {'<ip addr>': ['alias1', 'alias2', ...]}
+        {'<ip addr>': ['alias1', 'alias2', ...]}
 
-    CLI Example:
-    salt '*' hosts.list_hosts
+    CLI Example::
+
+        salt '*' hosts.list_hosts
     '''
     hfn = '/etc/hosts'
     ret = {}
@@ -26,12 +29,13 @@ def list_hosts():
         ret[comps[0]] = comps[1:]
     return ret
 
+
 def get_ip(host):
     '''
     Return the ip associated with the named host
 
-    CLI Example:
-    salt '*' hosts.get_ip <hostname>
+    CLI Example::
+        salt '*' hosts.get_ip <hostname>
     '''
     hosts = list_hosts()
     if not hosts:
@@ -43,39 +47,42 @@ def get_ip(host):
     # ip not found
     return ''
 
+
 def get_alias(ip):
     '''
     Return the list of aliases associated with an ip
 
-    CLI Example:
-    salt '*' hosts.get_alias <ip addr>
+    CLI Example::
+        salt '*' hosts.get_alias <ip addr>
     '''
     hosts = list_hosts()
-    if hosts.has_key(ip):
+    if ip in hosts:
         return hosts[ip]
     return []
 
+
 def has_pair(ip, alias):
     '''
     Return true if the alias is set
 
-    CLI Example:
-    salt '*' hosts.has_pair <ip> <alias>
+    CLI Example::
+        salt '*' hosts.has_pair <ip> <alias>
     '''
     hosts = list_hosts()
-    if not hosts.has_key(ip):
+    if ip not in hosts:
         return False
     if hosts[ip].count(alias):
         return True
     return False
 
+
 def set_host(ip, alias):
     '''
     Set the host entry in th hosts file for the given ip, this will overwrite
     any previous entry for the given ip
 
-    CLI Example:
-    salt '*' hosts.set_host <ip> <alias>
+    CLI Example::
+        salt '*' hosts.set_host <ip> <alias>
     '''
     hfn = '/etc/hosts'
     ovr = False
@@ -98,12 +105,13 @@ def set_host(ip, alias):
     open(hfn, 'w+').writelines(lines)
     return True
 
+
 def rm_host(ip, alias):
     '''
     Remove a host entry from the hosts file
 
-    CLI Example:
-    salt '*' hosts.rm_host <ip> <alias>
+    CLI Example::
+        salt '*' hosts.rm_host <ip> <alias>
     '''
     if not has_pair(ip, alias):
         return True
@@ -129,13 +137,14 @@ def rm_host(ip, alias):
     open(hfn, 'w+').writelines(lines)
     return True
 
+
 def add_host(ip, alias):
     '''
     Add a host to an existing entry, if the entry is not in place then create
     it with the given host
 
-    CLI Example:
-    salt '*' hosts.add_host <ip> <alias>
+    CLI Example::
+        salt '*' hosts.add_host <ip> <alias>
     '''
     hfn = '/etc/hosts'
     ovr = False
