@@ -2,15 +2,16 @@
 Module to manage Linux kernel modules
 '''
 
-# Import python libs
 import os
 
+
 def __virtual__():
     '''
     Only runs on Linux systems
     '''
     return 'kmod' if __grains__['kernel'] == 'Linux' else False
 
+
 def _new_mods(pre_mods, post_mods):
     '''
     Return a list of the new modules, pass an lsmod dict before running
@@ -24,6 +25,7 @@ def _new_mods(pre_mods, post_mods):
         post.add(mod['module'])
     return list(post.difference(pre))
 
+
 def _rm_mods(pre_mods, post_mods):
     '''
     Return a list of the new modules, pass an lsmod dict before running
@@ -37,12 +39,14 @@ def _rm_mods(pre_mods, post_mods):
         post.add(mod['module'])
     return list(pre.difference(post))
 
+
 def available():
     '''
     Return a list of all available kernel modules
 
-    CLI Example:
-    salt '*' kmod.available
+    CLI Example::
+
+        salt '*' kmod.available
     '''
     ret = []
     for path in __salt__['cmd.run']('modprobe -l').split('\n'):
@@ -53,24 +57,28 @@ def available():
             ret.append('.'.join(comps[:comps.index('ko')]))
     return ret
 
+
 def check_available(mod):
     '''
     Check to see if the speciified kernel module is available
 
-    CLI Example:
-    salt '*' kmod.check_available kvm
+    CLI Example::
+
+        salt '*' kmod.check_available kvm
     '''
     if available().count(mod):
         # the module is available, return True
         return True
     return False
 
+
 def lsmod():
     '''
     Return a dict containing information about currently loaded modules
 
-    CLI Example:
-    salt '*' kmod.lsmod
+    CLI Example::
+
+        salt '*' kmod.lsmod
     '''
     ret = []
     for line in __salt__['cmd.run']('lsmod').split('\n'):
@@ -90,24 +98,28 @@ def lsmod():
         ret.append(mdat)
     return ret
 
+
 def load(mod):
     '''
     Load the specified kernel module
 
-    CLI Example:
-    salt '*' kmod.load kvm
+    CLI Example::
+
+        salt '*' kmod.load kvm
     '''
     pre_mods = lsmod()
     data = __salt__['cmd.run_all']('modprobe {0}'.format(mod))
     post_mods = lsmod()
     return _new_mods(pre_mods, post_mods)
 
+
 def remove(mod):
     '''
     Remove the specified kernel module
 
-    CLI Example:
-    salt '*' kmod.remove kvm
+    CLI Example::
+
+        salt '*' kmod.remove kvm
     '''
     pre_mods = lsmod()
     data = __salt__['cmd.run_all']('modprobe -r {0}'.format(mod))
