@@ -1,20 +1,24 @@
 '''
 Module for viewing and modifying sysctl parameters
 '''
+
 import os
 
+
 def __virtual__():
     '''
     Only run on Linux systems
     '''
     return 'sysctl' if __grains__['kernel'] == 'Linux' else False
 
+
 def show():
     '''
     Return a list of sysctl parameters for this minion
 
-    CLI Example:
-    salt '*' sysctl.show
+    CLI Example::
+
+        salt '*' sysctl.show
     '''
     cmd = 'sysctl -a'
     ret = {}
@@ -28,17 +32,20 @@ def show():
         ret[comps[0]] = comps[1]
     return ret
 
+
 def get(name):
     '''
     Return a single sysctl parameter for this minion
 
-    CLI Example:
-    salt '*' sysctl.get net.ipv4.ip_forward
+    CLI Example::
+
+        salt '*' sysctl.get net.ipv4.ip_forward
     '''
     cmd = 'sysctl -n {0}'.format(name)
     out = __salt__['cmd.run'](cmd).strip()
     return out
 
+
 def assign(name, value):
     '''
     Assign a single sysctl parameter for this minion
@@ -53,12 +60,14 @@ def assign(name, value):
     ret[comps[0]] = comps[1]
     return ret
 
+
 def persist(name, value, config='/etc/sysctl.conf'):
     '''
     Assign and persist a simple sysctl paramater for this minion
 
-    CLI Example:
-    salt '*' sysctl.persist net.ipv4.ip_forward 1
+    CLI Example::
+
+        salt '*' sysctl.persist net.ipv4.ip_forward 1
     '''
     running = show()
     edited = False
@@ -84,7 +93,7 @@ def persist(name, value, config='/etc/sysctl.conf'):
             # This is the line to edit
             if str(comps[1]) == str(value):
                 # It is correct in the config, check if it is correct in /proc
-                if running.has_key(name):
+                if name in running:
                     if not running[name] == str(value):
                         assign(name, value)
                         return 'Updated'
@@ -97,4 +106,3 @@ def persist(name, value, config='/etc/sysctl.conf'):
     open(config, 'w+').writelines(nlines)
     assign(name, value)
     return 'Updated'
-
