@@ -1,21 +1,22 @@
 '''
 Module to provide MySQL compatibility to salt.
 
-In order to connect to MySQL, certain configuration is required 
+In order to connect to MySQL, certain configuration is required
 in /etc/salt/minion on the relevant minions. Some sample configs
-might look like:
+might look like::
 
-mysql.host: 'localhost'
-mysql.port: 3306
-mysql.user: 'root'
-mysql.pass: ''
-mysql.db: 'mysql'
+    mysql.host: 'localhost'
+    mysql.port: 3306
+    mysql.user: 'root'
+    mysql.pass: ''
+    mysql.db: 'mysql'
 '''
 
 import MySQLdb
 
 __opts__ = {}
 
+
 def connect():
     '''
     wrap authentication credentials here
@@ -38,13 +39,15 @@ def connect():
     db.autocommit(True)
     return db
 
+
 def status():
     '''
     Return the status of a MySQL server using the output
-    from the SHOW STATUS query.
+    from the ``SHOW STATUS`` query.
 
-    CLI Example:
-    salt '*' mysql.status
+    CLI Example::
+
+        salt '*' mysql.status
     '''
     ret = {}
     db = connect()
@@ -55,17 +58,18 @@ def status():
         ret[row[0]] = row[1]
     return ret
 
+
 def version():
     '''
     Return the version of a MySQL server using the output
-    from the SELECT VERSION() query.
+    from the ``SELECT VERSION()`` query.
 
-    CLI Example:
-    salt '*' mysql.version
+    CLI Example::
+
+        salt '*' mysql.version
     '''
     db = connect()
     cur = db.cursor()
     cur.execute('SELECT VERSION()')
     row = cur.fetchone()
     return row
-
