@@ -1,21 +1,28 @@
 '''
 Module for gathering and managing network information
 '''
-import subprocess
-import socket
+
 from string import ascii_letters, digits
+import socket
+import subprocess
+
 
 def _sanitize_host(host):
+    '''
+    Sanitize host string.
+    '''
     return "".join([
         c for c in host[0:255] if c in (ascii_letters + digits + '.')
     ])
 
+
 def ping(host):
     '''
     Performs a ping to a host
 
-    CLI Example:
-    salt '*' network.ping archlinux.org -c 4
+    CLI Example::
+
+        salt '*' network.ping archlinux.org -c 4
     '''
     cmd = 'ping -c 4 %s' % _sanitize_host(host)
 
@@ -24,12 +31,14 @@ def ping(host):
             stdout=subprocess.PIPE).communicate()[0]
     return out
 
+
 def netstat():
     '''
     Return information on open ports and states
 
-    CLI Example:
-    salt '*' network.netstat
+    CLI Example::
+
+        salt '*' network.netstat
     '''
     cmd = 'netstat -tulpnea'
     ret = []
@@ -41,36 +50,36 @@ def netstat():
             continue
         comps = line.split()
         if line.startswith('tcp'):
-            ret.append( {
-                'proto':          comps[0],
-                'recv-q':         comps[1],
-                'send-q':         comps[2],
-                'local-address':  comps[3],
+            ret.append({
+                'inode': comps[7],
+                'local-address': comps[3],
+                'program': comps[8],
+                'proto': comps[0],
+                'recv-q': comps[1],
                 'remote-address': comps[4],
-                'state':          comps[5],
-                'user':           comps[6],
-                'inode':          comps[7],
-                'program':        comps[8],
-            } )
+                'send-q': comps[2],
+                'state': comps[5],
+                'user': comps[6]})
         if line.startswith('udp'):
-            ret.append( {
-                'proto':          comps[0],
-                'recv-q':         comps[1],
-                'send-q':         comps[2],
-                'local-address':  comps[3],
+            ret.append({
+                'inode': comps[6],
+                'local-address': comps[3],
+                'program': comps[7],
+                'proto': comps[0],
+                'recv-q': comps[1],
                 'remote-address': comps[4],
-                'user':           comps[5],
-                'inode':          comps[6],
-                'program':        comps[7],
-            } )
+                'send-q': comps[2],
+                'user': comps[5]})
     return ret
 
+
 def traceroute(host):
     '''
     Performs a traceroute to a 3rd party host
 
-    CLI Example:
-    salt '*' network.traceroute archlinux.org
+    CLI Example::
+
+        salt '*' network.traceroute archlinux.org
     '''
     cmd = 'traceroute %s' % _sanitize_host(host)
     ret = []
@@ -84,25 +93,26 @@ def traceroute(host):
             continue
         comps = line.split()
         result = {
-            'count':    comps[0],
+            'count': comps[0],
             'hostname': comps[1],
-            'ip':       comps[2],
-            'ping1':    comps[3],
-            'ms1':      comps[4],
-            'ping2':    comps[5],
-            'ms2':      comps[6],
-            'ping3':    comps[7],
-            'ms3':      comps[8],
-        }
+            'ip': comps[2],
+            'ms1': comps[4],
+            'ms2': comps[6],
+            'ms3': comps[8],
+            'ping1': comps[3],
+            'ping2': comps[5],
+            'ping3': comps[7]}
         ret.append(result)
     return ret
 
+
 def dig(host):
     '''
     Performs a DNS lookup with dig
 
-    CLI Example:
-    salt '*' network.dig archlinux.org
+    CLI Example::
+
+        salt '*' network.dig archlinux.org
     '''
     cmd = 'dig %s' % _sanitize_host(host)
 
@@ -111,12 +121,14 @@ def dig(host):
             stdout=subprocess.PIPE).communicate()[0]
     return out
 
+
 def isportopen(host, port):
     '''
     Return status of a port
 
-    CLI Example:
-    salt '*' network.isportopen 127.0.0.1 22
+    CLI Example::
+
+        salt '*' network.isportopen 127.0.0.1 22
     '''
 
     if not (1 <= int(port) <= 65535):
@@ -126,3 +138,4 @@ def isportopen(host, port):
     out = sock.connect_ex((_sanitize_host(host), int(port)))
 
     return out
+
