@@ -3,51 +3,60 @@ A module to wrap pacman calls, since Arch is the best
 (https://wiki.archlinux.org/index.php/Arch_is_the_best)
 '''
 
+
 def __virtual__():
     '''
     Set the virtual pkg module if the os is Arch
     '''
     return 'pkg' if __grains__['os'] == 'Arch' else False
 
+
 def _list_removed(old, new):
     '''
     List the packages which have been removed between the two package objects
     '''
     pkgs = []
     for pkg in old:
-        if not new.has_key(pkg):
+        if pkg not in new:
             pkgs.append(pkg)
     return pkgs
 
+
 def available_version(name):
     '''
     The available version of the package in the repository
 
-    CLI Example:
-    salt '*' pkg.available_version <package name>
+    CLI Example::
+
+        salt '*' pkg.available_version <package name>
     '''
     return __salt__['cmd.run']('pacman -Sp --print-format %v {0}'.format(name))
 
+
 def version(name):
     '''
     Returns a version if the package is installed, else returns an empty string
 
-    CLI Example:
-    salt '*' pkg.version <package name>
+    CLI Example::
+
+        salt '*' pkg.version <package name>
     '''
     pkgs = list_pkgs()
-    if pkgs.has_key(name):
+    if name in pkgs:
         return pkgs[name]
     else:
         return ''
 
+
 def list_pkgs():
     '''
-    List the packages currently installed in a dict:
-    {'<package_name>': '<version>'}
+    List the packages currently installed as a dict::
 
-    CLI Example:
-    salt '*' pkg.list_pkgs
+        {'<package_name>': '<version>'}
+
+    CLI Example::
+
+        salt '*' pkg.list_pkgs
     '''
     cmd = 'pacman -Q'
     ret = {}
@@ -59,13 +68,16 @@ def list_pkgs():
         ret[comps[0]] = comps[1]
     return ret
 
+
 def refresh_db():
     '''
-    Just run a pacman -Sy, return a dict:
-    {'<database name>': Bool}
+    Just run a ``pacman -Sy``, return a dict::
 
-    CLI Example:
-    salt '*' pkg.refresh_db
+        {'<database name>': Bool}
+
+    CLI Example::
+
+        salt '*' pkg.refresh_db
     '''
     cmd = 'pacman -Sy'
     ret = {}
@@ -82,6 +94,7 @@ def refresh_db():
             ret[key] = True
     return ret
 
+
 def install(name, refresh=False):
     '''
     Install the passed package, add refresh=True to install with an -Sy
@@ -91,8 +104,9 @@ def install(name, refresh=False):
         {'<package>': {'old': '<old-version>',
                    'new': '<new-version>']}
 
-    CLI Example:
-    salt '*' pkg.install <package name>
+    CLI Example::
+
+        salt '*' pkg.install <package name>
     '''
     old = list_pkgs()
     cmd = 'pacman -S --noprogressbar --noconfirm ' + name
@@ -102,7 +116,7 @@ def install(name, refresh=False):
     new = list_pkgs()
     pkgs = {}
     for npkg in new:
-        if old.has_key(npkg):
+        if npkg in old:
             if old[npkg] == new[npkg]:
                 # no change in the package
                 continue
@@ -116,6 +130,7 @@ def install(name, refresh=False):
                           'new': new[npkg]}
     return pkgs
 
+
 def upgrade():
     '''
     Run a full system upgrade, a pacman -Syu
@@ -125,8 +140,9 @@ def upgrade():
         {'<package>': {'old': '<old-version>',
                    'new': '<new-version>']}
 
-    CLI Example:
-    salt '*' pkg.upgrade
+    CLI Example::
+
+        salt '*' pkg.upgrade
     '''
     old = list_pkgs()
     cmd = 'pacman -Syu --noprogressbar --noconfirm '
@@ -134,7 +150,7 @@ def upgrade():
     new = list_pkgs()
     pkgs = {}
     for npkg in new:
-        if old.has_key(npkg):
+        if npkg in old:
             if old[npkg] == new[npkg]:
                 # no change in the package
                 continue
@@ -148,14 +164,16 @@ def upgrade():
                           'new': new[npkg]}
     return pkgs
 
+
 def remove(name):
     '''
-    Remove a single package with pacman -R
+    Remove a single package with ``pacman -R``
 
-    Return a list containing the removed packages:
+    Return a list containing the removed packages.
 
-    CLI Example:
-    salt '*' pkg.remove <package name>
+    CLI Example::
+
+        salt '*' pkg.remove <package name>
     '''
     old = list_pkgs()
     cmd = 'pacman -R --noprogressbar --noconfirm ' + name
@@ -163,16 +181,17 @@ def remove(name):
     new = list_pkgs()
     return _list_removed(old, new)
 
+
 def purge(name):
     '''
     Recursively remove a package and all dependencies which were installed
-    with it, this will call a pacman -Rsc
+    with it, this will call a ``pacman -Rsc``
 
-    Return a list containing the removed packages:
+    Return a list containing the removed packages.
 
-    CLI Example:
-    salt '*' pkg.purge <package name>
+    CLI Example::
 
+        salt '*' pkg.purge <package name>
     '''
     old = list_pkgs()
     cmd = 'pacman -R --noprogressbar --noconfirm ' + name
