@@ -1,48 +1,54 @@
 '''
 Manage groups on Linux
 '''
-# Import python libs
+
 import grp
 
+
 def __virtual__():
     '''
     Set the user module if the kernel is Linux
     '''
     return 'group' if __grains__['kernel'] == 'FreeBSD' else False
 
+
 def add(name, gid=None):
     '''
     Add the specified group
 
-    CLI Example:
-    salt '*' group.add foo 3456
+    CLI Example::
+
+        salt '*' group.add foo 3456
     '''
     cmd = 'pw groupadd '
     if gid:
         cmd += '-g {0} '.format(gid)
-    cmd += name
-    
+    cmd = '{0} -n {1}'.format(cmd, name)
     ret = __salt__['cmd.run_all'](cmd)
 
     return not ret['retcode']
 
+
 def delete(name):
     '''
     Remove the named group
 
-    CLI Example:
-    salt '*' group.delete foo
+    CLI Example::
+
+        salt '*' group.delete foo
     '''
     ret = __salt__['cmd.run_all']('pw groupdel {0}'.format(name))
 
     return not ret['retcode']
 
+
 def info(name):
     '''
     Return information about a group
 
-    CLI Example:
-    salt '*' group.info foo
+    CLI Example::
+
+        salt '*' group.info foo
     '''
     grinfo = grp.getgrnam(name)
     return {'name': grinfo.gr_name,
@@ -50,24 +56,28 @@ def info(name):
             'gid': grinfo.gr_gid,
             'members': grinfo.gr_mem}
 
+
 def getent():
     '''
     Return info on all groups
 
-    CLI Example:
-    salt '*' group.getent
+    CLI Example::
+
+        salt '*' group.getent
     '''
     ret = []
     for grinfo in grp.getgrall():
         ret.append(info(grinfo.gr_name))
     return ret
 
+
 def chgid(name, gid):
     '''
     Change the default shell of the user
 
-    CLI Example:
-    salt '*' user.chshell foo /bin/zsh
+    CLI Example::
+
+        salt '*' user.chshell foo /bin/zsh
     '''
     pre_gid = __salt__['file.group_to_gid'](name)
     if gid == pre_gid:
