@@ -2,8 +2,10 @@
 Manage users with the useradd command
 '''
 
-import pwd
 import grp
+import os
+import pwd
+
 
 def __virtual__():
     '''
@@ -11,6 +13,7 @@ def __virtual__():
     '''
     return 'user' if __grains__['kernel'] == 'FreeBSD' else False
 
+
 def add(name,
         uid=None,
         gid=None,
@@ -20,16 +23,19 @@ def add(name,
     '''
     Add a user to the minion
 
-    CLI Example:
-    salt '*' user.add name <uid> <gid> <groups> <home> <shell>
+    CLI Example::
+
+        salt '*' user.add name <uid> <gid> <groups> <home> <shell>
     '''
+    if type(groups) == type(str()):
+        groups = groups.split(',')
     cmd = 'pw useradd -s {0} '.format(shell)
     if uid:
         cmd += '-u {0} '.format(uid)
     if gid:
         cmd += '-g {0} '.format(gid)
     if groups:
-        cmd += '-G {0} '.format(groups)
+        cmd += '-G {0} '.format(','.join(groups))
     if home:
         cmd += '-m -b {0} '.format(os.dirname(home))
     cmd += '-n {0}'.format(name)
@@ -37,12 +43,14 @@ def add(name,
 
     return not ret['retcode']
 
+
 def delete(name, remove=False, force=False):
     '''
     Remove a user from the minion
 
-    CLI Example:
-    salt '*' user.delete name True True
+    CLI Example::
+
+        salt '*' user.delete name True True
     '''
     cmd = 'pw userdel '
     if remove:
@@ -53,24 +61,28 @@ def delete(name, remove=False, force=False):
 
     return not ret['retcode']
 
+
 def getent():
     '''
     Return the list of all info for all users
 
-    CLI Example:
-    salt '*' user.getent
+    CLI Example::
+
+        salt '*' user.getent
     '''
     ret = []
     for data in pwd.getpwall():
         ret.append(info(data.pw_name))
     return ret
 
+
 def chuid(name, uid):
     '''
     Change the uid for a named user
 
-    CLI Example:
-    salt '*' user.chuid foo 4376
+    CLI Example::
+
+        salt '*' user.chuid foo 4376
     '''
     pre_info = info(name)
     if uid == pre_info['uid']:
@@ -83,12 +95,14 @@ def chuid(name, uid):
             return True
     return False
 
+
 def chgid(name, gid):
     '''
     Change the default group of the user
 
-    CLI Example:
-    salt '*' user.chgid foo 4376
+    CLI Example::
+
+        salt '*' user.chgid foo 4376
     '''
     pre_info = info(name)
     if gid == pre_info['gid']:
@@ -101,12 +115,14 @@ def chgid(name, gid):
             return True
     return False
 
+
 def chshell(name, shell):
     '''
     Change the default shell of the user
 
-    CLI Example:
-    salt '*' user.chshell foo /bin/zsh
+    CLI Example::
+
+        salt '*' user.chshell foo /bin/zsh
     '''
     pre_info = info(name)
     if shell == pre_info['shell']:
@@ -119,13 +135,15 @@ def chshell(name, shell):
             return True
     return False
 
+
 def chhome(name, home, persist=False):
     '''
     Change the home directory of the user, pass true for persist to copy files
     to the new home dir
 
-    CLI Example:
-    salt '*' user.chhome foo /home/users/foo True
+    CLI Example::
+
+        salt '*' user.chhome foo /home/users/foo True
     '''
     pre_info = info(name)
     if home == pre_info['home']:
@@ -141,13 +159,15 @@ def chhome(name, home, persist=False):
             return True
     return False
 
+
 def chgroups(name, groups, append=False):
     '''
     Change the groups this user belongs to, add append to append the specified
     groups
 
-    CLI Example:
-    salt '*' user.chgroups foo wheel,root True
+    CLI Example::
+
+        salt '*' user.chgroups foo wheel,root True
     '''
     if type(groups) == type(str()):
         groups = groups.split(',')
@@ -163,12 +183,14 @@ def chgroups(name, groups, append=False):
         return True
     return False
 
+
 def info(name):
     '''
     Return user information
 
-    CLI Example:
-    salt '*' user.info root
+    CLI Example::
+
+        salt '*' user.info root
     '''
     ret = {}
     data = pwd.getpwnam(name)
@@ -181,12 +203,14 @@ def info(name):
     ret['groups'] = list_groups(name)
     return ret
 
+
 def list_groups(name):
     '''
     Return a list of groups the named user belings to
 
-    CLI Example:
-    salt '*' user.groups foo
+    CLI Example::
+
+        salt '*' user.groups foo
     '''
     ugrp = set()
     for group in grp.getgrall():
