@@ -4,6 +4,7 @@ Execute calls on selinux
 
 import os
 
+
 def __virtual__():
     '''
     Check if the os is Linux, and then if selinux is running in permissive or
@@ -15,18 +16,21 @@ def __virtual__():
                 return 'selinux'
     return False
 
+
 def getenforce():
     '''
     Return the mode selinux is running in
 
-    CLE Example:
-    salt '*' selinux.getenforce
+    CLE Example::
+
+        salt '*' selinux.getenforce
     '''
     if open('/selinux/enforce', 'r').read() == '0':
         return 'Permissive'
     else:
         return 'Enforcing'
 
+
 def setenforce(mode):
     '''
     Set the enforcing mode
