@@ -4,6 +4,7 @@ Manage client ssh components
 
 import os
 
+
 def _refine_enc(enc):
     '''
     Return the properly formatted ssh value for the authorized encryption key
@@ -18,17 +19,24 @@ def _refine_enc(enc):
     else:
         return 'ssh-rsa'
 
+
 def _format_auth_line(
         key,
         enc,
         comment,
         options):
+    '''
+    Properly format user input.
+    '''
     line = ''
     if options:
         line += '{0} '.format(','.join(options))
     line += '{0} {1} {2}'.format(enc, key, comment)
     return line
 
+
+# FIXME: mutable types as default parameter values, NO!
+# http://goo.gl/ToU2z
 def _replace_auth_key(
         user,
         key,
@@ -66,12 +74,14 @@ def _replace_auth_key(
             lines.append(line)
     open(full, 'w+').writelines(lines)
 
+
 def host_keys(keydir=None):
     '''
     Return the minion's host keys
 
-    CLI Example:
-    salt '*' ssh.host_keys
+    CLI Example::
+
+        salt '*' ssh.host_keys
     '''
     # Set up the default keydir - needs to support sshd_config parsing in the
     # future
@@ -92,12 +102,14 @@ def host_keys(keydir=None):
                 keys[kname] = ''
     return keys
 
+
 def auth_keys(user, config='.ssh/authorized_keys'):
     '''
     Return the authorized keys for the specified user
 
-    CLI Example:
-    salt '*' ssh.auth_keys root
+    CLI Example::
+
+        salt '*' ssh.auth_keys root
     '''
     ret = {}
     uinfo = __salt__['user.info'](user)
@@ -131,15 +143,17 @@ def auth_keys(user, config='.ssh/authorized_keys'):
 
     return ret
 
+
 def rm_auth_key(user, key, config='.ssh/authorized_keys'):
     '''
     Remove an authorized key from the specified user's authorized key file
 
-    CLI Example:
-    salt '*' ssh.rm_auth_key <user> <key>
+    CLI Example::
+
+        salt '*' ssh.rm_auth_key <user> <key>
     '''
     current = auth_keys(user, config)
-    if current.has_key(key):
+    if key in current:
         # Remove the key
         uinfo = __salt__['user.info'](user)
         full = os.path.join(uinfo['home'], config)
@@ -173,6 +187,9 @@ def rm_auth_key(user, key, config='.ssh/authorized_keys'):
         return 'Key removed'
     return 'Key not present'
 
+
+# FIXME: mutable types as default parameter values, NO!
+# http://goo.gl/ToU2z
 def set_auth_key(
         user,
         key,
@@ -183,15 +200,16 @@ def set_auth_key(
     '''
     Add a key to the authorized_keys file
 
-    CLI Example:
-    salt '*' ssh.set_auth_key <user> <key> dsa '[]' .ssh/authorized_keys
+    CLI Example::
+
+        salt '*' ssh.set_auth_key <user> <key> dsa '[]' .ssh/authorized_keys
     '''
     enc = _refine_enc(enc)
-    ret = ''
+    ret = ''           # FIXME: where is ret used?
     replace = False
     uinfo = __salt__['user.info'](user)
     current = auth_keys(user, config)
-    if current.has_key(key):
+    if key in current:
         if not set(current[key]['options']) == set(options):
             replace = True
         if not current[key]['enc'] == enc:
