@@ -1,26 +1,26 @@
 '''
 A simple way of setting the output format for data from modules
 '''
-# Import Python libs
-import yaml
+
+import json
 import pprint
 
-# Conditionally import the json module
-try:
-    import json
-    JSON = True
-except ImportError:
-    JSON = False
+import yaml
 
-# Import Salt libs
 import salt.utils
 
 __all__ = ('get_outputter',)
 
+# FIXME: get rid of the JSON constant as it's acutally not needed anymore
+JSON = True
+
+
 def remove_colors():
     '''
     Acces all of the utility colors and change them to empy strings
     '''
+    pass
+
 
 class Outputter(object):
     '''
@@ -29,15 +29,16 @@ class Outputter(object):
     supports = None
 
     @classmethod
-    def check(klass, name):
-       # Don't advertise Outputter classes for optional modules
-       if hasattr(klass, "enabled") and not klass.enabled:
-           return False
-       return klass.supports == name
+    def check(cls, name):
+        # Don't advertise Outputter classes for optional modules
+        if hasattr(cls, "enabled") and not cls.enabled: # FIXME: class Outputter
+            return False                                # has no enabled member
+        return cls.supports == name
 
     def __call__(self, data, **kwargs):
         pprint.pprint(data)
 
+
 class HighStateOutputter(Outputter):
     '''
     Not a command line option, the HighStateOutputter is only meant to be used
@@ -45,6 +46,7 @@ class HighStateOutputter(Outputter):
     return data
     '''
     supports = 'highstate'
+
     def __call__(self, data, **kwargs):
         colors = salt.utils.get_colors(kwargs.get('color'))
         for host in data:
@@ -53,9 +55,11 @@ class HighStateOutputter(Outputter):
             if isinstance(data[host], list):
                 # Errors have been detected, list them in RED!
                 hcolor = colors['RED_BOLD']
-                hstrs.append('    {0}Data failed to compile:{1[ENDC]}'.format(hcolor, colors))
+                hstrs.append(('    {0}Data failed to compile:{1[ENDC]}'
+                              .format(hcolor, colors)))
                 for err in data[host]:
-                    hstrs.append('{0}----------\n    {1}{2[ENDC]}'.format(hcolor, err, colors))
+                    hstrs.append(('{0}----------\n    {1}{2[ENDC]}'
+                                  .format(hcolor, err, colors)))
             if isinstance(data[host], dict):
                 # Everything rendered as it should display the output
                 for tname, ret in data[host].items():
@@ -66,11 +70,10 @@ class HighStateOutputter(Outputter):
                     if ret['changes']:
                         tcolor = colors['CYAN']
                     comps = tname.split('.')
-                    hstrs.append('{0}----------\n    State: - {1}{2[ENDC]}'.format(
-                        tcolor,
-                        comps[0],
-                        colors
-                        ))
+                    hstrs.append(('{0}----------\n    State: - {1}{2[ENDC]}'
+                                  .format(tcolor, comps[0], colors)))
+                    # FIXME: string formating below should match the
+                    # style above
                     hstrs.append('    {0}Name:      {1}{2[ENDC]}'.format(
                         tcolor,
                         '.'.join(comps[1:-1]),
@@ -94,32 +97,33 @@ class HighStateOutputter(Outputter):
                     changes = '        Changes:   '
                     for key in ret['changes']:
                         if isinstance(ret['changes'][key], str):
-                            changes += key + ': ' + ret['changes'][key] + '\n                   '
+                            changes += (key + ': ' + ret['changes'][key] +
+                                        '\n                   ')
                         elif isinstance(ret['changes'][key], dict):
-                            changes += key + ': ' + pprint.pformat(ret['changes'][key]) + '\n                   '
+                            changes += (key + ': ' +
+                                        pprint.pformat(ret['changes'][key]) +
+                                        '\n                   ')
                         else:
-                            changes += key + ': ' + pprint.pformat(ret['changes'][key]) + '\n                   '
-                    hstrs.append('{0}{1}{2[ENDC]}'.format(
-                        tcolor,
-                        changes,
-                        colors
-                        ))
-            print '{0}{1}:{2[ENDC]}'.format(
-                hcolor,
-                host,
-                colors)
+                            changes += (key + ': ' +
+                                        pprint.pformat(ret['changes'][key]) +
+                                        '\n                   ')
+                    hstrs.append(('{0}{1}{2[ENDC]}'
+                                  .format(tcolor, changes, colors)))
+            print('{0}{1}:{2[ENDC]}'.format(hcolor, host, colors))
             for hstr in hstrs:
                 print hstr
-            
+
 
 class RawOutputter(Outputter):
     '''
     Raw output. This calls repr() on the returned data.
     '''
     supports = "raw"
+
     def __call__(self, data, **kwargs):
         print data
 
+
 class TxtOutputter(Outputter):
     '''
     Plain text output. Primarily for returning output from
@@ -127,6 +131,7 @@ class TxtOutputter(Outputter):
     on the shell when ran directly.
     '''
     supports = "txt"
+
     def __call__(self, data, **kwargs):
         if hasattr(data, "keys"):
             for key in data.keys():
@@ -137,17 +142,18 @@ class TxtOutputter(Outputter):
             # For non-dictionary data, just use print
             RawOutputter()(data)
 
+
 class JSONOutputter(Outputter):
     '''
     JSON output.
     '''
     supports = "json"
-    enabled  = JSON
+    enabled = JSON
 
     def __call__(self, data, **kwargs):
         try:
             # A good kwarg might be: indent=4
-            if kwargs.has_key('color'):
+            if 'color' in kwargs:
                 kwargs.pop('color')
             ret = json.dumps(data, **kwargs)
         except TypeError:
@@ -155,17 +161,19 @@ class JSONOutputter(Outputter):
             ret = json.dumps({})
         print ret
 
+
 class YamlOutputter(Outputter):
     '''
     Yaml output. All of the cool kids are doing it.
     '''
     supports = "yaml"
 
-    def __call__(self, data,  **kwargs):
-        if kwargs.has_key('color'):
+    def __call__(self, data, **kwargs):
+        if 'color' in kwargs:
             kwargs.pop('color')
         print yaml.dump(data, **kwargs)
 
+
 def get_outputter(name=None):
     '''
     Factory function for returning the right output class.
@@ -175,7 +183,7 @@ def get_outputter(name=None):
         printout(ret)
     '''
     # Return an actual instance of the correct output class
-    for i in Outputter.__subclasses__():
-        if i.check(name):
+    for i in Outputter.__subclasses__():  # FIXME: class Outputter has no
+        if i.check(name):                 # __subclasses__ member
             return i()
     return Outputter()
