@@ -1,18 +1,21 @@
 '''
-Pure python state renderer, the sls file should contain a function called sls
-which returns high state data
+Pure python state renderer
+
+The sls file should contain a function called ``sls`` which returns high state
+data
 '''
 
-# Import python libs
 import imp
 import os
 
+
 def render(template, env='', sls=''):
     '''
     Render the python module's components
     '''
     if not os.path.isfile(template):
         return {}
+
     mod = imp.load_source(
             os.path.basename(template).split('.')[0],
             template
@@ -21,4 +24,5 @@ def render(template, env='', sls=''):
     mod.grains = __grains__
     mod.env = env
     mod.sls = sls
+
     return mod.run()
