@@ -1,14 +1,16 @@
 '''
-The default rendering engine, yaml_jinja, this renderer will take a yaml file
-with the jinja template and render it to a high data format for salt states.
+The default rendering engine, process yaml with the jinja2 templating engine
+
+This renderer will take a yaml file with the jinja2 template and render it to a
+high data format for salt states.
 '''
 
-# Import python libs
 import os
 
 # Import Third Party libs
-import yaml
 from jinja2 import Template
+import yaml
+
 
 def render(template, env='', sls=''):
     '''
@@ -16,12 +18,14 @@ def render(template, env='', sls=''):
     '''
     if not os.path.isfile(template):
         return {}
+
     passthrough = {}
     passthrough['salt'] = __salt__
     passthrough['grains'] = __grains__
     passthrough['env'] = env
     passthrough['sls'] = sls
+
     template = Template(open(template, 'r').read())
     yaml_data = template.render(**passthrough)
-    return yaml.load(yaml_data)
 
+    return yaml.safe_load(yaml_data)
