@@ -11,17 +11,15 @@ Available Functions
 The cmd state only has a single function, the ``run`` function
 
 run
-~~~
+    Execute a command given certian conditions
 
-Execute a command given certian conditions
+    A simple exampe:
 
-A simple exampe:
+    .. code-block:: yaml
 
-.. code-block:: yaml
-
-    date > /tmp/salt-run:
-      cmd:
-        - run
+        date > /tmp/salt-run:
+        cmd:
+            - run
 
 Only run if another execution returns sucessfully, in this case truncate
 syslog if there is no disk space:
@@ -35,9 +33,10 @@ syslog if there is no disk space:
 
 '''
 
+import grp
 import os
 import pwd
-import grp
+
 
 def run(name,
         onlyif=None,
@@ -74,21 +73,26 @@ def run(name,
            'changes': {},
            'result': False,
            'comment': ''}
+
     if onlyif:
         if __salt__['cmd.retcode'](onlyif) != 0:
             ret['comment'] = 'onlyif exec failed'
             ret['result'] = True
             return ret
+
     if unless:
         if __salt__['cmd.retcode'](unless) == 0:
             ret['comment'] = 'unless executed successfully'
             ret['result'] = True
             return ret
+
     if not os.path.isdir(cwd):
         ret['comment'] = 'Desired working directory is not available'
         return ret
+
     puid = os.geteuid()
     pgid = os.getegid()
+
     if group:
         try:
             egid = grp.getgrnam(group).gr_gid
@@ -112,3 +116,4 @@ def run(name,
     os.setegid(pgid)
     return ret
 
+watcher = run
