@@ -60,13 +60,14 @@ something like this:
         - source: salt://code/flask
 '''
 
+import difflib
+import hashlib
 import os
 import shutil
 import tempfile
-import difflib
-import hashlib
 import traceback
 
+
 def _makedirs(path):
     '''
     Ensure that the directory containing this path is available.
@@ -74,6 +75,7 @@ def _makedirs(path):
     if not os.path.isdir(os.path.dirname(path)):
         os.makedirs(os.path.dirname(path))
 
+
 def _is_bin(path):
     '''
     Return True if a file is a bin, just checks for NULL char, this should be
@@ -83,11 +85,13 @@ def _is_bin(path):
         return True
     return False
 
-def _mako(sfn):
+
+def _mako(sfn, name, source, user, group, mode, env):
     '''
     Render a jinja2 template, returns the location of the rendered file,
     return False if render fails.
-    Returns:
+    Returns::
+
         {'result': bool,
          'data': <Error data or rendered file path>}
     '''
@@ -110,11 +114,13 @@ def _mako(sfn):
         return {'result': False,
                 'data': trb}
 
-def _jinja(sfn):
+
+def _jinja(sfn, name, source, user, group, mode, env):
     '''
     Render a jinja2 template, returns the location of the rendered file,
     return False if render fails.
-    Returns:
+    Returns::
+
         {'result': bool,
          'data': <Error data or rendered file path>}
     '''
@@ -128,15 +134,22 @@ def _jinja(sfn):
         passthrough = {}
         passthrough['salt'] = __salt__
         passthrough['grains'] = __grains__
+        passthrough['name'] = name
+        passthrough['source'] = source
+        passthrough['user'] = user
+        passthrough['group'] = group
+        passthrough['mode'] = mode
+        passthrough['env'] = env
         template = Template(open(sfn, 'r').read())
         open(tgt, 'w+').write(template.render(**passthrough))
         return {'result': True,
-        	    'data': tgt}
+                    'data': tgt}
     except:
         trb = traceback.format_exc()
         return {'result': False,
                 'data': trb}
 
+
 def symlink(name, target, force=False, makedirs=False):
     '''
     Create a symlink
@@ -165,7 +178,8 @@ def symlink(name, target, force=False, makedirs=False):
         if makedirs:
             _makedirs(name)
         ret['result'] = False
-        ret['comment'] = 'Directory {0} for symlink is not present'.format(os.path.dirname(name))
+        ret['comment'] = ('Directory {0} for symlink is not present'
+                          .format(os.path.dirname(name)))
         return ret
     if os.path.islink(name):
         # The link exists, verify that it matches the target
@@ -182,7 +196,8 @@ def symlink(name, target, force=False, makedirs=False):
             os.remove(name)
         else:
             ret['result'] = False
-            ret['comment'] = 'File exists where the symlink {0} should be'.format(name)
+            ret['comment'] = ('File exists where the symlink {0} should be'
+                              .format(name))
             return ret
     elif os.path.isdir(name):
         # It is not a link or a file, it is a dir, error out
@@ -190,7 +205,8 @@ def symlink(name, target, force=False, makedirs=False):
             shutil.rmtree(name)
         else:
             ret['result'] = False
-            ret['comment'] = 'Direcotry exists where the symlink {0} should be'.format(name)
+            ret['comment'] = ('Direcotry exists where the symlink {0} '
+                              'should be'.format(name))
             return ret
     if not os.path.exists(name):
         # The link is not present, make it
@@ -199,6 +215,7 @@ def symlink(name, target, force=False, makedirs=False):
         ret['changes']['new'] = name
         return ret
 
+
 def absent(name):
     '''
     Verify that the named file or directory is absent, this will work to
@@ -234,6 +251,7 @@ def absent(name):
     ret['comment'] = 'File {0} is not present'.format(name)
     return ret
 
+
 def managed(name,
         source,
         user=None,
@@ -265,7 +283,7 @@ def managed(name,
 
     mode
         The permissions to set on this file, aka 644, 0775, 4664
-    
+
     template
         If this setting is applied then the named templating engine will be
         used to render the downloaded file, currently jinja and mako are
@@ -279,21 +297,30 @@ def managed(name,
     '''
     if mode:
         mode = str(mode)
-    ret =  {'name': name,
-            'changes': {},
-            'result': True,
-            'comment': ''}
+    ret = {'changes': {},
+           'comment': '',
+           'name': name,
+           'result': True}
     # Gather the source file from the server
     sfn = ''
     source_sum = {}
     if template:
         sfn = __salt__['cp.cache_file'](source, __env__)
         t_key = '_{0}'.format(template)
-        if globals().has_key(t_key):
-            data = globals()[t_key](sfn)
+        if t_key in globals():
+            data = globals()[t_key](
+                    sfn,
+                    name,
+                    source,
+                    user,
+                    group,
+                    mode,
+                    __env__
+                    )
         else:
             ret['result'] = False
-            ret['comment'] = 'Specified template format {0} is not supported'.format(template)
+            ret['comment'] = ('Specified template format {0} is not supported'
+                              .format(template))
             return ret
         if data['result']:
             sfn = data['data']
@@ -330,7 +357,9 @@ def managed(name,
             else:
                 slines = open(sfn, 'rb').readlines()
                 nlines = open(name, 'rb').readlines()
-                ret['changes']['diff'] = '\n'.join(difflib.unified_diff(slines, nlines))
+                ret['changes']['diff'] = ('\n'.join(difflib
+                                                    .unified_diff(slines,
+                                                                  nlines)))
             # Pre requs are met, and the file needs to be replaced, do it
             if not __opts__['test']:
                 shutil.copy(sfn, name)
@@ -346,7 +375,7 @@ def managed(name,
         if group:
             if group != perms['lgroup']:
                 perms['cgroup'] = group
-        if perms.has_key('cuser') or perms.has_key('cgroup'):
+        if 'cuser' in perms or 'cgroup' in perms:
             if not __opts__['test']:
                 __salt__['file.chown'](
                         name,
@@ -366,13 +395,14 @@ def managed(name,
             if user != __salt__['file.get_user'](name):
                 ret['result'] = False
                 ret['comment'] = 'Failed to change user to {0} '.format(user)
-            elif perms.has_key('cuser'):
+            elif 'cuser' in perms:
                 ret['changes']['user'] = user
         if group:
             if group != __salt__['file.get_group'](name):
                 ret['result'] = False
-                ret['comment'] += 'Failed to change group to {0} '.format(group)
-            elif perms.has_key('cgroup'):
+                ret['comment'] += ('Failed to change group to {0} '
+                                   .format(group))
+            elif 'cgroup' in perms:
                 ret['changes']['group'] = group
 
         if not ret['comment']:
@@ -387,6 +417,12 @@ def managed(name,
         # It is a new file, set the diff accordingly
         ret['changes']['diff'] = 'New file'
         # Apply the new file
+        if not sfn:
+            sfn = __salt__['cp.cache_file'](source, __env__)
+        if not sfn:
+            ret['result'] = False
+            ret['comment'] = 'Source file {0} not found'.format(source)
+            return ret
         if not __opts__['test']:
             if not os.path.isdir(os.path.dirname(name)):
                 if makedirs:
@@ -409,7 +445,7 @@ def managed(name,
         if group:
             if group != perms['lgroup']:
                 perms['cgroup'] = group
-        if perms.has_key('cuser') or perms.has_key('cgroup'):
+        if 'cuser' in perms or 'cgroup' in perms:
             if not __opts__['test']:
                 __salt__['file.chown'](
                         name,
@@ -429,13 +465,13 @@ def managed(name,
             if user != __salt__['file.get_user'](name):
                 ret['result'] = False
                 ret['comment'] += 'User not changed '
-            elif perms.has_key('cuser'):
+            elif 'cuser' in perms:
                 ret['changes']['user'] = user
         if group:
             if group != __salt__['file.get_group'](name):
                 ret['result'] = False
                 ret['comment'] += 'Group not changed '
-            elif perms.has_key('cgroup'):
+            elif 'cgroup' in perms:
                 ret['changes']['group'] = group
 
         if not ret['comment']:
@@ -447,6 +483,7 @@ def managed(name,
             ret['comment'] = 'File ' + name + ' is in the correct state'
         return ret
 
+
 def directory(name,
         user=None,
         group=None,
@@ -468,7 +505,7 @@ def directory(name,
 
     mode
         The permissions to set on this directory, aka 755
-    
+
     makedirs
         If the directory is located in a path without a parent directory, then
         the the state will fail. If makedirs is set to True, then the parent
@@ -477,13 +514,14 @@ def directory(name,
     '''
     if mode:
         mode = str(mode)
-    ret =  {'name': name,
-            'changes': {},
-            'result': True,
-            'comment': ''}
+    ret = {'name': name,
+           'changes': {},
+           'result': True,
+           'comment': ''}
     if os.path.isfile(name):
         ret['result'] = False
-        ret['comment'] = 'Specifed location {0} exists and is a file'.format(name)
+        ret['comment'] = ('Specifed location {0} exists and is a file'
+                          .format(name))
         return ret
     if not os.path.isdir(name):
         # The dir does not exist, make it
@@ -514,7 +552,7 @@ def directory(name,
     if group:
         if group != perms['lgroup']:
             perms['cgroup'] = group
-    if perms.has_key('cuser') or perms.has_key('cgroup'):
+    if 'cuser' in perms or 'cgroup' in perms:
         if not __opts__['test']:
             __salt__['file.chown'](
                     name,
@@ -534,13 +572,13 @@ def directory(name,
         if user != __salt__['file.get_user'](name):
             ret['result'] = False
             ret['comment'] = 'Failed to change user to {0} '.format(user)
-        elif perms.has_key('cuser'):
+        elif 'cuser' in perms:
             ret['changes']['user'] = user
     if group:
         if group != __salt__['file.get_group'](name):
             ret['result'] = False
             ret['comment'] += 'Failed to change group to {0} '.format(group)
-        elif perms.has_key('cgroup'):
+        elif 'cgroup' in perms:
             ret['changes']['group'] = group
 
     if not ret['comment']:
@@ -552,9 +590,8 @@ def directory(name,
         ret['comment'] = 'Directory {0} is in the correct state'.format(name)
     return ret
 
-def recurse(name,
-        source,
-        __env__='base'):
+
+def recurse(name, source, __env__='base'):
     '''
     Recurse through a subdirectory on the master and copy said subdirecory
     over to the specified path.
@@ -577,7 +614,8 @@ def recurse(name,
         if os.path.exists(name):
             # it is not a dir, but it exists - fail out
             ret['result'] = False
-            ret['comment'] = 'The path {0} exists and is not a directory'.format(name)
+            ret['comment'] = ('The path {0} exists and is not a directory'
+                              .format(name))
             return ret
         os.makedirs(name)
     for fn_ in __salt__['cp.cache_dir'](source, __env__):
@@ -587,7 +625,8 @@ def recurse(name,
                     os.path.join(
                         __opts__['cachedir'],
                         'files',
-                        __env__
+                        __env__,
+                        source[7:]
                         )
                     )
                 )
